@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-"""H5py/hdf5 utils"""
+"""HDF5 functions, and utils, and generators, OH MY!"""
 from h5._meta import __version__
 from h5.core import (
     __h5py_version__,
@@ -19,8 +19,7 @@ from h5.core import (
     h5py_obj_dataset_gen,
 )
 
-
-__all__ = [
+__all__ = (
     "__version__",
     "__h5py_version__",
     "h5py_obj_attrs_gen",
@@ -37,4 +36,4 @@ __all__ = [
     "h5_datasets_gen_from_fspath",
     "h5_attrs_dict",
     "h5_attrs_gen_from_fspath",
-]
+)
