@@ -2,6 +2,6 @@
 """Package metadata/info"""
 
 __title__ = 'h5'
-__version__ = '0.4.0'
+__version__ = '0.5.0'
 __license__ = 'MIT'
-__description__ = 'h5py utilities'
+__description__ = 'H5py utils'
